@@ -1,8 +1,10 @@
 package WWW::MeGa::Item::Image;
-use WWW::MeGa::Item;
-our @ISA = qw(WWW::MeGa::Item);
+use strict;
+use warnings;
 
-our $VERSION = '0.09_1';
+use base 'WWW::MeGa::Item';
+
+our $VERSION = '0.09_2';
 
 # the image representation of a image is a image ;)
 
